@@ -3,13 +3,13 @@ app_server <- function(input, output, session) {
   style <- app_theme_style()
   ch_env$stream_output <- ""
   app_add_history(input)
-  is_test <- unlist(options("chattr-shiny-test")) %||% FALSE
-  if (is_test) {
-    chattr_use("test")
+  if (is_test()) {
+    use_switch(.file = package_file("apptest/test.yml"), .silent = TRUE)
     invalidate_time <- 1000
   } else {
     invalidate_time <- 100
   }
+  defaults <- chattr_defaults(type = "chat")
   auto_invalidate <- shiny::reactiveTimer(invalidate_time)
   session$sendCustomMessage(type = "refocus", message = list(NULL))
 
@@ -24,8 +24,7 @@ app_server <- function(input, output, session) {
 
   output$stream <- renderText({
     auto_invalidate()
-    if (ch_r_state() == "busy") {
-      ch_env$stream_output <- paste0(ch_env$stream_output, ch_r_output())
+    if (ch_app_status() == "busy") {
       markdown(ch_env$stream_output)
     }
   })
@@ -52,16 +51,13 @@ app_server <- function(input, output, session) {
   })
 
   observeEvent(input$submit, {
-    if (input$prompt != "" && ch_r_state() == "idle") {
-      ch_history_append(user = input$prompt)
-      app_add_user(input$prompt)
-      updateTextAreaInput(inputId = "prompt", value = "")
-      session$sendCustomMessage(type = "refocus", message = list(NULL))
-      ch_r_submit(
-        prompt = input$prompt,
-        defaults = chattr_defaults(type = "chat")
-      )
+    if (input$prompt != "" && ch_app_status() == "idle") {
+      ch_submit(defaults, input$prompt, shiny = TRUE)
     }
+    ch_history_append(user = input$prompt)
+    app_add_user(input$prompt)
+    session$sendCustomMessage(type = "refocus", message = list(NULL))
+    updateTextAreaInput(inputId = "prompt", value = "")
   })
 
   observeEvent(input$open, {
@@ -86,17 +82,18 @@ app_server <- function(input, output, session) {
 
   observe({
     auto_invalidate()
-    if (ch_r_state() == "idle" && ch_env$stream_output != "") {
+    curr_output <- ch_app_output() %||% ""
+    if (ch_app_status() == "idle" && curr_output != "") {
       Sys.sleep(0.02)
-      ch_history_append(assistant = ch_env$stream_output)
-      app_add_assistant(ch_env$stream_output, input)
-      ch_env$stream_output <- ""
+      ch_history_append(assistant = ch_app_output())
+      app_add_assistant(ch_app_output(), input)
+      ch_app_output(reset = TRUE)
     }
   })
 
   observe({
     auto_invalidate()
-    error <- ch_r_error()
+    error <- NULL
     if (!is.null(error)) {
       stopApp()
       abort(error)
