@@ -108,6 +108,9 @@ chattr_defaults <- function(type = "default",
           if (length(td$prompt) > 0 && any(grepl("\n", td$prompt))) {
             td$prompt <- unlist(strsplit(td$prompt, split = "\n"))
           }
+          if (length(td$system_msg) > 0 && any(grepl("\n", td$system_msg))) {
+            td$system_msg <- unlist(strsplit(td$system_msg, split = "\n"))
+          }
           chattr_defaults_set(
             arguments = td,
             type = type
@@ -128,17 +131,21 @@ chattr_defaults <- function(type = "default",
 
 as_ch_model <- function(x, type) {
   x$type <- type
-
   provider <- tolower(x$provider)
-
   sp_provider <- unlist(strsplit(provider, " - "))
   if (length(sp_provider) > 1) {
     first_cl <- paste0("ch_", prep_class_name(sp_provider[[1]]))
   } else {
     first_cl <- NULL
   }
-
+  x_mode <- x$mode %||% ""
+  if (x_mode == "ellmer") {
+    ch_ellmer <- "ch_ellmer"
+  } else {
+    ch_ellmer <- NULL
+  }
   class(x) <- c(
+    ch_ellmer,
     paste0("ch_", prep_class_name(provider)),
     first_cl,
     "ch_model"
@@ -148,13 +155,10 @@ as_ch_model <- function(x, type) {
 
 prep_class_name <- function(x) {
   x <- tolower(x)
-  x <- gsub(" - ", "_", x)
-  x <- gsub("-", "_", x)
-  x <- gsub(" \\(", "_", x)
-  x <- gsub(" ", "_", x)
-  x <- gsub("\\(", "_", x)
-  x <- gsub("\\) ", "_", x)
-  x <- gsub("\\)", "_", x)
+  look_for <- c(" - ", "-", " \\(", " ", "\\(", "\\) ", "\\)")
+  for (item in look_for) {
+    x <- gsub(item, "_", x)
+  }
   x
 }
 
@@ -235,6 +239,14 @@ chattr_defaults_set <- function(arguments = list(),
   ch_env$defaults[[type]] <- arguments
 }
 
+bulleted_list <- function(x) {
+  if (length(x) == 1) {
+    x <- unlist(strsplit(x, split = "\n"))
+  }
+  x <- process_prompt(x)
+  paste0("* ", x, collapse = " \n")
+}
+
 process_prompt <- function(x) {
   if (is.null(x)) {
     return(x)
