@@ -1,13 +1,13 @@
-#' @importFrom purrr map_chr map_lgl map imap set_names walk flatten
-#' @importFrom purrr iwalk discard keep imap_lgl reduce transpose
-#' @importFrom rlang %||% abort is_named is_interactive is_na
+#' @importFrom purrr map_chr map_lgl map set_names walk imap
+#' @importFrom purrr iwalk discard keep imap_lgl reduce
+#' @importFrom rlang %||% abort is_named is_interactive
 #' @importFrom utils capture.output head menu
 #' @importFrom clipr write_clip
 #' @importFrom bslib bs_theme
 #' @importFrom grDevices rgb
 #' @import rstudioapi
 #' @import processx
-#' @import callr
+#' @import ellmer
 #' @import httr2
 #' @import shiny
 #' @import glue
@@ -20,3 +20,5 @@
 ## usethis namespace: end
 ch_env <- new.env()
 ch_env$valid_uis <- c("console", "chat", "notebook", "script")
+ch_env$stream_output <- ""
+ch_env$stream_status <- "idle"
