@@ -1,5 +1,5 @@
-test_that("Set to GPT3.5", {
-  expect_snapshot(chattr_use("gpt35"))
+test_that("Set to ollama", {
+  expect_snapshot(chattr_use("ollama"))
 })
 
 test_that("UI output is as expected", {
