@@ -1,5 +1,5 @@
 test_that("Creation and printing ch_request objects", {
-  def <- test_simulate_model("gpt35.yml")
+  def <- test_simulate_model("gpt41.yml")
   x <- list()
   x$provider <- "Test Provider"
   x$type <- "chat"
@@ -15,3 +15,9 @@ test_that("OS functions work", {
     os_get() %in% c("mac", "win", "unix")
   )
 })
+
+test_that("Print history works", {
+  expect_snapshot(
+    print_history(list(list(role = "user", content = "test")))
+  )
+})
